@@ -1,12 +1,13 @@
 import os
+from concurrent.futures import ThreadPoolExecutor
+
 import pandas as pd
 from dotenv import load_dotenv
-from pymongo import DESCENDING, MongoClient, ASCENDING, TEXT
-from concurrent.futures import ThreadPoolExecutor
-from pymongo.errors import OperationFailure, DocumentTooLarge
+from pymongo import ASCENDING, DESCENDING, TEXT, MongoClient
+from pymongo.errors import DocumentTooLarge, OperationFailure
 
-from inoopa_utils.inoopa_logging import create_logger
 from inoopa_utils.custom_types.decision_makers import DecisionMaker
+from inoopa_utils.inoopa_logging import create_logger
 
 load_dotenv()
 
@@ -116,21 +117,32 @@ class DbManagerMongo:
             [("linkedin_url", ASCENDING)],
         ]
         fields_to_index_company = [
+            [("country", ASCENDING)],
             [("address.string_address", ASCENDING)],
             [("address.region", ASCENDING)],
             [("address.postal_code", ASCENDING)],
             [("legal_form_type", ASCENDING)],
             [("best_website", ASCENDING)],
+            [("best_website", ASCENDING), ("country", ASCENDING)],
             [("best_website.website", ASCENDING)],
             [("best_email", ASCENDING)],
+            [("best_email", ASCENDING), ("country", ASCENDING)],
             [("best_phone", ASCENDING)],
+            [("best_phone", ASCENDING), ("country", ASCENDING)],
             [("board_members.name", ASCENDING)],
-            [("country", ASCENDING)],
             [("employee_category_code", ASCENDING)],
+            [("employee_category_code", ASCENDING), ("country", ASCENDING)],
             [("establishments.name", ASCENDING)],
             [("name", ASCENDING)],
             [("status", ASCENDING)],
             [("name_text", TEXT)],
+            [("description_id", ASCENDING)],
+            [("description_id", ASCENDING), ("country", ASCENDING)],
+            # For Inoopa NACE filtering (used in nace_code_correction)
+            [("nace_codes", ASCENDING)],
+            [("nace_codes.source", ASCENDING)],
+            [("country", ASCENDING), ("nace_codes", ASCENDING)],
+            [("country", ASCENDING), ("nace_codes.source", ASCENDING)],
         ]
         fields_to_index_website_structure = [
             [("_id", ASCENDING)],  # Base url
